@@ -23,10 +23,10 @@
 //! # }
 //! ```
 //!
-//! See more [examples](https://github.com/mehcode/config-rs/tree/master/examples) for
+//! See more [examples](https://github.com/rust-cli/config-rs/tree/main/examples) for
 //! general usage information.
 
-#![cfg_attr(docsrs, feature(doc_auto_cfg))]
+#![cfg_attr(docsrs, feature(doc_cfg))]
 #![warn(clippy::print_stderr)]
 #![warn(clippy::print_stdout)]
 
@@ -59,3 +59,7 @@ pub use crate::map::Map;
 pub use crate::source::AsyncSource;
 pub use crate::source::Source;
 pub use crate::value::{Value, ValueKind};
+
+#[doc = include_str!("../README.md")]
+#[cfg(doctest)]
+pub struct ReadmeDoctests;
